==> qttranslations-opensource-src-5.6.2.tar.xz: qttranslations-opensource-src-5.6.2/translations/qtwebengine_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Authentifizierung erforderlich</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Anmelden</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig machen</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Einfügen und Stil anpassen</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Link in diesem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Link in neuem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Seite schließen</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Neu laden</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Verzeichnis zum Hochladen</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Javascript-Warnung - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Javascript-Bestätigung - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Javascript-Abfrage - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
</context>
<context>
    <name>QtWebEngineExperimentalPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineViewExperimental</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineViewExperimental erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineViewport</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineViewport erstellt werden</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineLoadRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineLoadRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNavigationRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineNavigationRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineCertificateError</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineCertificateError erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineDownloadItem erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineNewViewRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineSettings erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Es kann keine separate Instanz der Klasse NavigationHistory erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Es kann keine separate Instanz der Klasse FullScreenRequest erstellt werden</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineErrorPage erstellt werden</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Verbinde zu Proxy &quot;%1&quot; unter Verwendung von:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2</source>
        <translation>Geben Sie Nutzername und Passwort für &quot;%1&quot; auf %2 ein</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src-5.8.0.tar.xz: qttranslations-opensource-src-5.8.0/translations/qtwebengine_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>View Page Source</source>
        <translation>Seitenquelltext anzeigen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Auswahl aufheben</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Unter Umgehung des Caches neu laden</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig machen</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Einfügen und Stil anpassen</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Link in diesem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Link in neuem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Background Tab</source>
        <translation>Link in neuem Reiter im Hintergrund öffnen</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Seite schließen</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Auswahl aufheben</translation>
    </message>
    <message>
        <source>Save &amp;Page</source>
        <translation>Seite s&amp;peichern</translation>
    </message>
    <message>
        <source>&amp;View Page Source</source>
        <translation>Seiten&amp;quelltext anzeigen</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Neu laden</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Verzeichnis zum Hochladen</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Javascript-Warnung - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Javascript-Bestätigung - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Javascript-Abfrage - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineDownloadItem erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineSettings erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Es kann keine separate Instanz der Klasse NavigationHistory erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Es kann keine separate Instanz der Klasse FullScreenRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of %1</source>
        <translation>Es kann keine separate Instanz der Klasse %1 erstellt werden</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineErrorPage erstellt werden</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Verbinde zu Proxy &quot;%1&quot; unter Verwendung von:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Geben Sie Nutzername und Passwort für &quot;%1&quot; auf %2://%3 ein</translation>
    </message>
</context>
</TS>
